@@ -13,7 +13,8 @@
 #' @param extract.indels logical, at present, the only option is TRUE
 #' @param consensus logical, at present, the only option is TRUE
 #' @param extract.haps logical specifying whether to separate each genotype into alleles based on a delimiting character
-#' @param gt.split character to delimit alleles within genotypes
+# @param gt.split character to delimit alleles within genotypes
+#' @param unphased_as_NA logical indicating how to handle alleles in unphased genotypes
 #' @param ref.seq reference sequence (DNAbin) for the region being converted
 #' @param start.pos chromosomal position for the start of the ref.seq
 #' @param verbose logical specifying whether to produce verbose output
@@ -36,14 +37,14 @@
 #' 
 #' 
 #' The \strong{ploidy} of the samples is inferred from the first non-missing genotype.
-#' The option \code{gt.split} is used to split this genotype into alleles and these are counted.
-#' Values for \code{gt.split} are typically '|' for phased data or '/' for unphased data.
-#' Note that this option is an exact match and not used in a regular expression, as the 'sep' parameter in \code{\link{vcfR2genind}} is used.
+# The option \code{gt.split} is used to split this genotype into alleles and these are counted.
+# Values for \code{gt.split} are typically '|' for phased data or '/' for unphased data.
+# Note that this option is an exact match and not used in a regular expression, as the 'sep' parameter in \code{\link{vcfR2genind}} is used.
 #' All samples and all variants within each sample are assumed to be of the same ploid.
 #' 
 #' 
 #' Conversion of \strong{haploid data} is fairly straight forward.
-#' The options \code{consensus}, \code{extract.haps} and \code{gt.split} are not relevant here.
+#' The options \code{consensus} and \code{extract.haps} are not relevant here.
 #' When vcfR2DNAbin encounters missing data in the vcf data (NA) it is coded as an ambiguous nucleotide (n) in the DNAbin object.
 #' When no reference sequence is provided (option \code{ref.seq}), a DNAbin object consisting only of variant sites is created.
 #' When a reference sequence and a starting position are provided the entire sequence, including invariant sites, is returned.
@@ -52,13 +53,13 @@
 #' 
 #' 
 #' Conversion of \strong{diploid data} presents a number of scenarios.
-#' When the option \code{consensus} is TRUE, each genotype is split into two alleles using gt.split and the two alleles are converted into their IUPAC ambiguity code.
+#' When the option \code{consensus} is TRUE, each genotype is split into two alleles and the two alleles are converted into their IUPAC ambiguity code.
 #' This results in one sequence for each diploid sample.
 #' This may be an appropriate path when you have unphased data.
 #' Note that functions called downstream of this choice may handle IUPAC ambiguity codes in unexpected manners.
-#' When extract.haps is set to TRUE, each genotype is split into two alleles using gt.split.
+#' When extract.haps is set to TRUE, each genotype is split into two alleles.
 #' These alleles are inserted into two sequences.
-#' Thsi results in two sequences per diploid sample.
+#' This results in two sequences per diploid sample.
 #' Note that this really only makes sense if you have phased data.
 #' The options ref.seq and start.pos are used as in halpoid data.
 #' 
@@ -77,11 +78,49 @@
 #' 
 #' 
 #' @seealso 
-#' \href{http://cran.r-project.org/package=ape}{ape}
+#' \href{https://cran.r-project.org/package=ape}{ape}
+#' 
+#' 
+#' @examples 
+#' library(ape)
+#' data(vcfR_test)
+#' 
+#' # Create an example reference sequence.
+#' nucs <- c('a','c','g','t')
+#' set.seed(9)
+#' myRef <- as.DNAbin(matrix(nucs[round(runif(n=20, min=0.5, max=4.5))], nrow=1))
+#' 
+#' # Recode the POS data for a smaller example.
+#' set.seed(99)
+#' vcfR_test@fix[,'POS'] <- sort(sample(10:20, size=length(getPOS(vcfR_test))))
+#' 
+#' # Just vcfR
+#' myDNA <- vcfR2DNAbin(vcfR_test)
+#' seg.sites(myDNA)
+#' image(myDNA)
+#' 
+#' # ref.seq, no start.pos
+#' myDNA <- vcfR2DNAbin(vcfR_test, ref.seq = myRef)
+#' seg.sites(myDNA)
+#' image(myDNA)
+#' 
+#' # ref.seq, start.pos = 4.
+#' # Note that this is the same as the previous example but the variants are shifted.
+#' myDNA <- vcfR2DNAbin(vcfR_test, ref.seq = myRef, start.pos = 4)
+#' seg.sites(myDNA)
+#' image(myDNA)
+#' 
+#' # ref.seq, no start.pos, unphased_as_NA = FALSE
+#' myDNA <- vcfR2DNAbin(vcfR_test, unphased_as_NA = FALSE, ref.seq = myRef)
+#' seg.sites(myDNA)
+#' image(myDNA)
+#' 
+#' 
 #' 
 #' @export
 vcfR2DNAbin <- function( x, extract.indels = TRUE , consensus = FALSE,
-                         extract.haps = TRUE, gt.split="|",
+                         extract.haps = TRUE,
+                         unphased_as_NA = TRUE,
                          ref.seq = NULL, start.pos = NULL,
                          verbose = TRUE )
 {
@@ -103,17 +142,29 @@ vcfR2DNAbin <- function( x, extract.indels = TRUE , consensus = FALSE,
     ref.seq <- as.matrix(ref.seq)
   }
   
+  # Check start.pos
+  if( is.null(start.pos) & !is.null(ref.seq) ){
+    if( verbose == TRUE ){
+      warning("start.pos == NULL, this means that I do not know where the variants are located in the ref.seq. I'll try start.pos == 1, but results may be unexpected")
+    }
+    start.pos <- 1
+  }
+  
   # Extract indels.
   # Currently the only option is TRUE.
   if( extract.indels == TRUE ){
     x <- extract.indels(x)
+    if( verbose == TRUE ){
+      message(paste("After extracting indels,", nrow(x), "variants remain."))
+    }
   } else {
     stop("extract.indels == FALSE is not currently implemented.")
   }
   
   # Save POS in case we need it.
   # i.e., for inserting variants into a matrix.
-  pos <- as.numeric(x@fix[,'POS'])
+#  pos <- as.numeric(x@fix[,'POS'])
+  pos <- getPOS(x)
   
   # If we think we have variants we should extract them.
   # Our GT matrix may contain zero rows, all NA or data.
@@ -132,10 +183,13 @@ vcfR2DNAbin <- function( x, extract.indels = TRUE , consensus = FALSE,
 #  if( class(x) == "vcfR" ){
 #    first.gt <- x@gt[ ,-1 ][ !is.na(x@gt[,-1]) ][1]
     if( consensus == TRUE & extract.haps == FALSE ){
-      x <- extract.gt( x, return.alleles = TRUE, allele.sep = gt.split )       
-      x <- alleles2consensus( x, sep = gt.split )
+#      x <- extract.gt( x, return.alleles = TRUE, allele.sep = gt.split )
+#      x <- alleles2consensus( x, sep = gt.split )
+      x <- extract.gt( x, return.alleles = TRUE )
+      x <- alleles2consensus( x )
     } else {
-      x <- extract.haps( x, gt.split = gt.split, verbose = verbose )
+#      x <- extract.haps( x, gt.split = gt.split, verbose = verbose )
+      x <- extract.haps( x, unphased_as_NA = unphased_as_NA, verbose = verbose )
     }
   }
 
@@ -161,14 +215,14 @@ vcfR2DNAbin <- function( x, extract.indels = TRUE , consensus = FALSE,
     )
     colnames(x) <- colnames(variants)
 
-    # Populate with variants.
+    # Populate matrix of reference sequences with variants.
     # We need to subset the variant data to the region of interest.
     # First we remove variants above the region.
     # Then we remove variants below this region.
     # Then we rescale the region to be one-based.
-    variants <- variants[ pos < start.pos + dim(ref.seq)[2], ]
-    pos <- pos[ pos < start.pos + dim(ref.seq)[2] ]    
-    variants <- variants[ pos >= start.pos, ]
+    variants <- variants[ pos < start.pos + dim(ref.seq)[2], , drop = FALSE]
+    pos <- pos[ pos < start.pos + dim(ref.seq)[2] ]
+    variants <- variants[ pos >= start.pos, , drop = FALSE]
     pos <- pos[ pos >= start.pos ]
     pos <- pos - start.pos + 1
     x[pos,] <- variants
@@ -191,132 +245,4 @@ vcfR2DNAbin <- function( x, extract.indels = TRUE , consensus = FALSE,
 }
 
 
-vcfR2DNAbin1 <- function( x, extract.indels = TRUE , consensus = TRUE,
-                           extract.haps = FALSE, gt.split="|",
-                           ref.seq = NULL, start.pos = NULL,
-                           verbose = TRUE )
-    
-  {
-  # Sanitize input.
-  if( class(x) == 'chromR' )
-  {
-    x <- x@vcf
-  }
-  if( class(x) != 'vcfR' )
-  {
-    stop( "Expecting an object of class chromR or vcfR" )
-  }
-  if( consensus == TRUE & extract.haps == TRUE){
-    stop("consensus and extract_haps both set to true. These options are incompatible. A haplotype should not be ambiguous.")
-  }
-  if( !is.null(start.pos) & class(start.pos) == "character" ){
-    start.pos <- as.integer(start.pos)
-  }
-  
-  # Check and sanitize ref.seq.
-  if( class(ref.seq) != 'DNAbin' & !is.null(ref.seq) ){
-    stop( paste("expecting ref.seq to be of class DNAbin but it is of class", class(ref.seq)) )
-  }
-  if( is.list(ref.seq) ){
-    ref.seq <- as.matrix(ref.seq)
-  }
-  
-  # Extract indels.
-  # Currently the only option is TRUE.
-  if( extract.indels == TRUE ){
-    x <- extract.indels(x)
-  } else {
-    stop("extract.indels == FALSE is not currently implemented.")
-  }
-  
-  # If we removed all variants, return.
-#  if( nrow(x@fix) < 1 & is.null(ref.seq) ){
-#    return( x )
-#    return( NA )
-#  }
-  
-  # Save POS in case we need it.
-  # i.e., for inserting variants into a matrix.
-  pos <- as.numeric(x@fix[,'POS'])
-  
-  if( extract.haps == FALSE ){
-    x <- extract.gt( x, return.alleles = TRUE, allele.sep = gt.split )
-  } else if( extract.haps == TRUE & nrow(x@gt) > 0 ){
-#    x <- extract_haps(x, gt_split=gt.split, verbose = verbose)
-    x <- extract.haps( x, gt.split = gt.split, verbose = verbose )
-  } else if( extract.haps == TRUE & nrow(x@gt) == 0 ){
-#    ref.seq <- as.matrix(ref.seq)
-    out.seq <- matrix( as.character(ref.seq),
-                       nrow = dim(ref.seq)[2],
-                       ncol = ncol(x) * 2,
-                       byrow = FALSE
-    )
-    colnames(out.seq) <- paste(rep(colnames(x@gt)[-1], each=2), rep(c(0,1), times=ncol(x@gt[,-1]), sep="_"))
-    out.seq <- ape::as.DNAbin(t(out.seq))
-    return( out.seq )
-  } else {
-    stop( "Invalid specification of extract.haps.\nShould be a logical." )
-  }
-
-  # Strategies to convert genotypes (with a delimiter) to nucleotides.
-  # If extract.haps was set to TRUE, then our data is effectively haploid now.
-  ploid <- length(unlist( strsplit( x[!is.na(x)][1], split=gt.split, fixed=TRUE ) ))
-
-  
-  if( ploid == 1 ){
-    # Haploid case
-    x[is.na(x)] <- 'n'
-    if( nrow(x) > 1 ){
-      x <- apply(x, MARGIN=2, tolower)
-    } else if( nrow(x) == 1 ){
-      x <- apply(x, MARGIN=2, tolower)
-      x <- matrix(x, nrow=1, dimnames = list( NULL, names(x)))
-    }
-  } else if ( ploid == 2 & consensus == TRUE ){
-    # Diploid case
-    x <- alleles2consensus( x, sep = gt.split, NA_to_n = TRUE )
-    x <- apply(x, MARGIN=2, tolower)
-  } else if ( ploid == 2 & consensus == FALSE ){
-    stop( "Ploidy is 2 but consensus is set to FALSE.\nGenotypes must be converted to a nucleotide.\nConsider setting consensus to TRUE." )
-#    stop( "function only valid for diploid and haploid genotypes." )
-  } else if ( ploid > 2 & extract_haps == FALSE ){
-    stop( "Ploidy is greater than 2 but extract_haps is set to FALSE.\nGenotypes must be converted to a nucleotide.\nConsider setting extract_haps to TRUE." )
-  }
-  
-  # Fill with reference sequence.
-  if( !is.null(ref.seq) ){
-    if( class(ref.seq) == "list" & inherits(ref.seq, "DNAbin") ){
-      ref.seq <- as.matrix(ref.seq)
-    }
-    
-    # Subset the vcf data to our region of interest.
-    end.pos <- start.pos + dim(ref.seq)[2] - 1
-    x <- x[ pos >= start.pos & pos <= end.pos, , drop = FALSE ]
-    
-    # Subset pos to our region of interest
-    # and set to new coordinate system.
-    pos <- pos[ pos >= start.pos & pos <= end.pos ]
-    pos <- pos - start.pos + 1
-    
-    # Create a matrix with the same number of columns as vcf data
-    # and the number of rows to match the sequence length.
-    out.seq <- matrix( as.character(ref.seq),
-                       nrow = dim(ref.seq)[2],
-                       ncol = ncol(x),
-                       byrow = FALSE
-    )
-    colnames(out.seq) <- colnames(x)
-    
-#    pos <- pos - start.pos + 1
-    out.seq[pos,] <- x
-    x <- out.seq
-  }
-
-  # DNAbin characters must be lower case.
-  x <- ape::as.DNAbin(t(x))
-  x
-}
-
-
-
 
